@@ -1,11 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-# -*- coding: utf-8 -*-
 """
 Minimal Atom feed writer.
 """
-from __future__ import absolute_import, division, unicode_literals, print_function
-
-import sys
 import datetime
 import hashlib
 import xml.etree.ElementTree as etree
@@ -19,7 +15,7 @@ ATOM_NS = "{http://www.w3.org/2005/Atom}"
 XML_NS = "{http://www.w3.org/XML/1998/namespace}"
 
 
-class FeedEntry(object):
+class FeedEntry:
     """
     Atom feed entry.
 
@@ -125,7 +121,7 @@ def write_atom(dest, entries, author, title, address, updated=None, link=None,
         if entries:
             updated = max(entry.updated for entry in entries)
         else:
-            updated = datetime.datetime.utcnow()
+            updated = datetime.datetime.now(datetime.timezone.utc)
 
     root = etree.Element(ATOM_NS + 'feed')
 
@@ -165,11 +161,7 @@ def write_atom(dest, entries, author, title, address, updated=None, link=None,
     tree = etree.ElementTree(root)
 
     def write(f):
-        if sys.version_info[:2] < (2, 7):
-            _etree_py26_write(f, tree)
-        else:
-            tree.write(f, xml_declaration=True, default_namespace=ATOM_NS[1:-1],
-                       encoding=str('utf-8'))
+        tree.write(f, xml_declaration=True, default_namespace=ATOM_NS[1:-1], encoding="utf-8")
 
     if hasattr(dest, 'write'):
         write(dest)
@@ -178,35 +170,6 @@ def write_atom(dest, entries, author, title, address, updated=None, link=None,
             write(f)
 
 
-def _etree_py26_write(f, tree):
-    """
-    Compatibility workaround for ElementTree shipped with py2.6
-    """
-    f.write("<?xml version='1.0' encoding='utf-8'?>\n".encode('utf-8'))
-
-    if etree.VERSION[:3] == '1.2':
-        def fixtag(tag, namespaces):
-            if tag == XML_NS + 'lang':
-                return 'xml:lang', ""
-            if '}' in tag:
-                j = tag.index('}') + 1
-                tag = tag[j:]
-                xmlns = ''
-            if tag == 'feed':
-                xmlns = ('xmlns', str('http://www.w3.org/2005/Atom'))
-                namespaces['http://www.w3.org/2005/Atom'] = 'xmlns'
-            return tag, xmlns
-    else:
-        fixtag = etree.fixtag
-
-    old_fixtag = etree.fixtag
-    etree.fixtag = fixtag
-    try:
-        tree.write(f, encoding=str('utf-8'))
-    finally:
-        etree.fixtag = old_fixtag
-
-
 def _get_id(owner, date, content):
     """
     Generate an unique Atom id for the given content
@@ -222,5 +185,8 @@ def _get_id(owner, date, content):
         h.update(",".encode('utf-8'))
 
     if date is None:
-        date = datetime.datetime(1970, 1, 1)
-    return "tag:{0},{1}:/{2}".format(owner, date.strftime('%Y-%m-%d'), h.hexdigest())
+        date = datetime.datetime(
+            1970, 1, 1,
+            tzinfo = datetime.timezone.utc
+        )
+    return f"tag:{owner},{date.strftime('%Y-%m-%d')}:/{h.hexdigest()}"
