@@ -1,9 +1,5 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import os
 import sys
 
@@ -18,7 +14,7 @@ from .shared import shared_function
 if sys.version_info[0] < 3:
     import commands
 try:
-    import commands.quickstart
+    import commands.quickstart  # noqa F401 unused import
     assert False
 except ImportError:
     # OK
