@@ -1,28 +1,25 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import sys
 import re
 
 from asv.results import iter_results_for_machine
+from asv import util
 
 from . import tools
-from .tools import dummy_packages, get_default_environment_type
-from .test_workflow import basic_conf
+from .tools import get_default_environment_type
 
 
-def test_continuous(capfd, basic_conf):
-    tmpdir, local, conf, machine_file = basic_conf
+def test_continuous(capfd, basic_conf_2):
+    tmpdir, local, conf, machine_file = basic_conf_2
 
     python = "{0[0]}.{0[1]}".format(sys.version_info)
     env_type = get_default_environment_type(conf, python)
     env_spec = ("-E", env_type + ":" + python)
 
     # Check that asv continuous runs
-    tools.run_asv_with_conf(conf, 'continuous', "master^", '--show-stderr',
+    tools.run_asv_with_conf(conf, 'continuous',
+                            f"{util.git_default_branch()}^", '--show-stderr',
                             '--bench=params_examples.track_find_test',
                             '--bench=params_examples.track_param',
                             '--bench=time_examples.TimeSuite.time_example_benchmark_1',
@@ -33,7 +30,10 @@ def test_continuous(capfd, basic_conf):
     text, err = capfd.readouterr()
     assert "SOME BENCHMARKS HAVE CHANGED SIGNIFICANTLY" in text
     assert "PERFORMANCE INCREASED" in text or "PERFORMANCE DECREASED" in text
-    assert "+               1                6     6.00  params_examples.track_find_test(2)" in text
+    # Check output, but not the whole row
+    pattern = r"params_examples\.track_find_test\(2\) \[orangutan\/\w+-py"
+    assert re.search(pattern, text) is not None
+
     assert "params_examples.ClassOne" in text
 
     # Check rounds were interleaved (timing benchmark was run twice)
