@@ -1,18 +1,11 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 from os.path import join
 
-import six
-
 from asv import machine
 
 
 def test_machine(tmpdir):
-    tmpdir = six.text_type(tmpdir)
+    tmpdir = str(tmpdir)
 
     m = machine.Machine.load(
         interactive=False,
@@ -34,7 +27,7 @@ def test_machine(tmpdir):
 
 
 def test_machine_defaults(tmpdir):
-    tmpdir = six.text_type(tmpdir)
+    tmpdir = str(tmpdir)
 
     m = machine.Machine.load(
         interactive=True,
