@@ -1,8 +1,13 @@
 import os
+
 from setuptools import setup
 
+# This file is a template, and will be rendered before executed.
+# So the double curly brackets will become single after rendering, and
+# when executed, this will work as expected
+content = 'env = {{}}\n'.format(repr(dict(os.environ)))  # noqa W291 see above comment
 with open('asv_test_repo/build_time_env.py', 'w') as f:
-    f.write("env = {{}}\n".format(repr(dict(os.environ))))
+    f.write(content)
 
 setup(name='asv_test_repo',
       version="{version}",
