@@ -1,25 +1,18 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import os
 import datetime
 import shutil
 from os.path import join
 
-import six
-
-from asv import results, runner, util
 import pytest
 
-from .tools import example_results
+from asv import results, runner, util
 
 
 def _truncate_floats(item, digits=5):
     if isinstance(item, float):
-        fmt = '{{:.{}e}}'.format(digits - 1)
+        fmt = f'{{:.{digits - 1}e}}'
         return float(fmt.format(item))
     elif isinstance(item, list):
         return [_truncate_floats(x, digits) for x in item]
@@ -30,13 +23,13 @@ def _truncate_floats(item, digits=5):
 
 
 def test_results(tmpdir):
-    tmpdir = six.text_type(tmpdir)
+    tmpdir = str(tmpdir)
 
-    timestamp1 = datetime.datetime.utcnow()
+    timestamp1 = datetime.datetime.now(datetime.timezone.utc)
     duration = 1.5
 
     resultsdir = join(tmpdir, "results")
-    for i in six.moves.xrange(10):
+    for i in range(10):
         r = results.Results(
             {'machine': 'foo',
              'arch': 'x86_64'},
@@ -53,16 +46,17 @@ def test_results(tmpdir):
 
         values = {
             'suite1.benchmark1': {'result': [x1], 'number': [1],
-                                  'samples': [[x1,x1]], 'params': [['a']],
+                                  'samples': [[x1, x1]], 'params': [['a']],
                                   'version': "1", 'profile': b'\x00\xff'},
             'suite1.benchmark2': {'result': [x2], 'number': [1],
-                                  'samples': [[x2,x2,x2]], 'params': [],
+                                  'samples': [[x2, x2, x2]], 'params': [],
                                   'version': "1", 'profile': b'\x00\xff'},
             'suite2.benchmark1': {'result': [x3], 'number': [None],
                                   'samples': [None], 'params': [['c']],
                                   'version': None, 'profile': b'\x00\xff'},
             'suite3.benchmark1': {'result': [x1, x2], 'number': [1, 1],
-                                  'samples': [[x1,x1], [x2,x2,x3]], 'params': [['c', 'd']],
+                                  'samples': [[x1, x1], [x2, x2, x3]],
+                                  'params': [['c', 'd']],
                                   'version': None, 'profile': b'\x00\xff'}
         }
 
@@ -144,7 +138,7 @@ def test_get_result_hash_from_prefix(tmpdir):
     shutil.copyfile(machine_json, join(str(machine_dir), 'machine.json'))
 
     for f in ['e5b6cdbc', 'e5bfoo12']:
-        open(join(str(machine_dir), '{0}-py2.7-Cython-numpy1.8.json'.format(f)), 'a').close()
+        open(join(str(machine_dir), f'{f}-py2.7-Cython-numpy1.8.json'), 'a').close()
 
     # check unique, valid case
     full_commit = results.get_result_hash_from_prefix(str(results_dir), 'cheetah', 'e5b6')
@@ -161,7 +155,7 @@ def test_get_result_hash_from_prefix(tmpdir):
     assert 'one of multiple commits' in str(excinfo.value)
 
 
-def test_backward_compat_load(example_results):
+def test_backward_compat_load(example_results): # noqa F811 redefinition of the imported fixture,it can be removed when the fixture is moved to conftest.py file and the import deleted
     resultsdir = example_results
     filename = join('cheetah', '624da0aa-py2.7-Cython-numpy1.8.json')
 
@@ -172,10 +166,16 @@ def test_backward_compat_load(example_results):
 
 def test_json_timestamp(tmpdir):
     # Check that per-benchmark timestamps are saved as JS timestamps in the result file
-    tmpdir = six.text_type(tmpdir)
+    tmpdir = str(tmpdir)
 
-    stamp0 = datetime.datetime(1970, 1, 1)
-    stamp1 = datetime.datetime(1971, 1, 1)
+    stamp0 = datetime.datetime(
+        1970, 1, 1,
+        tzinfo = datetime.timezone.utc
+    )
+    stamp1 = datetime.datetime(
+        1971, 1, 1,
+        tzinfo = datetime.timezone.utc
+    )
     duration = 1.5
 
     r = results.Results({'machine': 'mach'},
@@ -204,17 +204,17 @@ def test_json_timestamp(tmpdir):
     assert values['duration'] == duration
 
 
-def test_iter_results(capsys, tmpdir, example_results):
-    dst = os.path.join(six.text_type(tmpdir), 'example_results')
+def test_iter_results(capsys, tmpdir, example_results): # noqa F811 noqa F811 redefinition of the imported fixture,it can be removed when the fixture is moved to conftest.py file and the import deleted
+    dst = os.path.join(str(tmpdir), 'example_results')
     shutil.copytree(example_results, dst)
 
     path = os.path.join(dst, 'cheetah')
 
     skip_list = [
         'machine.json',
-        'aaaaaaaa-py2.7-Cython-numpy1.8.json', # malformed file
-        'bbbbbbbb-py2.7-Cython-numpy1.8.json', # malformed file
-        'cccccccc-py2.7-Cython-numpy1.8.json', # malformed file
+        'aaaaaaaa-py2.7-Cython-numpy1.8.json',  # malformed file
+        'bbbbbbbb-py2.7-Cython-numpy1.8.json',  # malformed file
+        'cccccccc-py2.7-Cython-numpy1.8.json',  # malformed file
     ]
 
     files = [f for f in os.listdir(path) if f.endswith('.json') and f not in skip_list]
@@ -238,7 +238,7 @@ def test_filename_format():
     r = results.Results({'machine': 'foo'}, [], "commit", 0, "", "env", {})
     assert r._filename == join("foo", "commit-env.json")
 
-    r = results.Results({'machine': 'foo'}, [], "hash", 0, "", "a"*128, {})
+    r = results.Results({'machine': 'foo'}, [], "hash", 0, "", "a" * 128, {})
     assert r._filename == join("foo", "hash-env-e510683b3f5ffe4093d021808bc6ff70.json")
 
 
@@ -250,7 +250,7 @@ def test_remove_samples():
 
     v1 = runner.BenchmarkResult(result=[True], samples=[[1]], number=[1],
                                 profile=None, errcode=0, stderr='')
-    v2 = runner.BenchmarkResult(result=[True]*3, samples=[[1],[2],[3]], number=[1,1,1],
+    v2 = runner.BenchmarkResult(result=[True] * 3, samples=[[1], [2], [3]], number=[1, 1, 1],
                                 profile=None, errcode=0, stderr='')
 
     r.add_result(benchmark1, v1, record_samples=True)
@@ -287,8 +287,9 @@ def test_table_formatting():
     table = "\n".join(results._format_benchmark_result(result, benchmark, max_width=80))
     assert table == expected
 
-    benchmark = {'params': [["'a'", "'b'", "'c'"], ["[1]", "[2]"]], 'param_names': ['param1', 'param2'], "unit": "seconds"}
-    result = list(zip([1, 2, None, 4, 5, float('nan')], [None]*6))
+    benchmark = {'params': [["'a'", "'b'", "'c'"], ["[1]", "[2]"]],
+                 'param_names': ['param1', 'param2'], "unit": "seconds"}
+    result = list(zip([1, 2, None, 4, 5, float('nan')], [None] * 6))
     expected = ("======== ======== =======\n"
                 "--            param2     \n"
                 "-------- ----------------\n"
