@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
 import os
 import sys
 import time
+
 import pytest
 
 from asv import util
@@ -37,8 +34,12 @@ sys.stdout.write("Stdout before waiting\n")
 sys.stderr.write("Stderr before waiting\n")
 sys.stdout.flush()
 sys.stderr.flush()
-subprocess.call([sys.executable, "-c",
-    "import sys, subprocess; subprocess.call([sys.executable, '-c', 'import time; time.sleep(360)'])"])
+subprocess.call([
+    sys.executable,
+    "-c",
+    "import sys, subprocess; subprocess.call("
+    "[sys.executable, '-c', 'import time; time.sleep(360)'])"
+])
 sys.stdout.write("Stdout after waiting\n")
 sys.stderr.write("Stderr after waiting\n")
     """)
@@ -98,7 +99,7 @@ for j in range(3):
     time.sleep(1.0)
 """
     output = util.check_output([sys.executable, "-c", code], timeout=1.5)
-    assert output == '.'*3
+    assert output == '.' * 3
 
     try:
         util.check_output([sys.executable, "-c", code], timeout=0.5)
@@ -162,7 +163,7 @@ def test_large_output():
     # More data than a pipe buffer can hold
     data = util.check_output([sys.executable, "-c",
                               "import sys; [sys.stdout.write('x'*1000) for j in range(5000)]"])
-    assert data == 'x'*5000000
+    assert data == 'x' * 5000000
 
 
 # This *does* seem to work, only seems untestable somehow...
