@@ -1,29 +1,17 @@
-# -*- coding: utf-8 -*-
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-import re
 import glob
 import os
-import shutil
 import sys
-import datetime
 import json
+import shutil
+from os.path import join, isfile, abspath, relpath, dirname
 
-import six
 import pytest
 
-from os.path import abspath, dirname, join, isfile, relpath
-
-from asv import config, environment, util
-from asv.results import iter_results_for_machine
-from asv.util import check_output, which
+from asv import config, util
 
 from . import tools
-from .tools import dummy_packages, get_default_environment_type
-
 
 dummy_values = (
     (6, 1),
@@ -32,7 +20,7 @@ dummy_values = (
 )
 
 def generate_basic_conf(tmpdir, repo_subdir='', values=dummy_values, dummy_packages=True):
-    tmpdir = six.text_type(tmpdir)
+    tmpdir = str(tmpdir)
     local = abspath(dirname(__file__))
     os.chdir(tmpdir)
 
@@ -83,22 +71,23 @@ def basic_conf(tmpdir, dummy_packages):
     return generate_basic_conf(tmpdir)
 
 
+@pytest.mark.skipif(tools.HAS_PYPY or (os.name == 'nt'), reason="Flaky on pypy and windows")
 def test_run_publish(capfd, basic_conf):
     tmpdir, local, conf, machine_file = basic_conf
     tmpdir = util.long_path(tmpdir)
 
     conf.matrix = {
         "req": dict(conf.matrix),
-        "env":{"SOME_TEST_VAR": ["1"]},
+        "env": {"SOME_TEST_VAR": ["1"]},
     }
 
     # Tests a typical complete run/publish workflow
-    ret = tools.run_asv_with_conf(conf, 'run', "master", '--steps=2',
+    ret = tools.run_asv_with_conf(conf, 'run', f"{util.git_default_branch()}", '--steps=2',
                                   '--quick', '--show-stderr', '--profile',
                                   '-a', 'warmup_time=0',
                                   '--durations=5',
                                   _machine_file=machine_file)
-    assert ret is None
+    assert ret == 2
     text, err = capfd.readouterr()
 
     assert len(os.listdir(join(tmpdir, 'results_workflow', 'orangutan'))) == 5
@@ -126,7 +115,7 @@ def test_run_publish(capfd, basic_conf):
     with open(filename, 'r') as fp:
         data = json.load(fp)
         assert len(data) == 2
-        assert isinstance(data[0][0], six.integer_types)  # revision
+        assert isinstance(data[0][0], int)  # revision
         assert len(data[0][1]) == 3
         assert len(data[1][1]) == 3
         assert isinstance(data[0][1][0], float)
@@ -135,12 +124,12 @@ def test_run_publish(capfd, basic_conf):
 
     # Check that the skip options work
     capfd.readouterr()
-    tools.run_asv_with_conf(conf, 'run', "master", '--steps=2',
+    tools.run_asv_with_conf(conf, 'run', f"{util.git_default_branch()}", '--steps=2',
                             '--quick', '--skip-existing-successful',
                             '--bench=time_secondary.track_value',
                             '--skip-existing-failed',
                             _machine_file=join(tmpdir, 'asv-machine.json'))
-    tools.run_asv_with_conf(conf, 'run', "master", '--steps=2',
+    tools.run_asv_with_conf(conf, 'run', f"{util.git_default_branch()}", '--steps=2',
                             '--bench=time_secondary.track_value',
                             '--quick', '--skip-existing-commits',
                             _machine_file=join(tmpdir, 'asv-machine.json'))
@@ -149,7 +138,7 @@ def test_run_publish(capfd, basic_conf):
 
     # Check EXISTING and --environment work
     python = "{0[0]}.{0[1]}".format(sys.version_info)
-    env_type = get_default_environment_type(conf, python)
+    env_type = tools.get_default_environment_type(conf, python)
     env_spec = ("-E", env_type + ":" + python)
     tools.run_asv_with_conf(conf, 'run', "EXISTING", '--quick',
                             '--bench=time_secondary.track_value',
